==> connectagram_1.2.10.orig.tar.gz: connectagram-1.2.10/translations/connectagram_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Kette </translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Wird geladen</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <source>Definitions</source>
        <translation>Definitionen</translation>
    </message>
    <message>
        <source>Downloading definition...</source>
        <translation>Definition herunterladen...</translation>
    </message>
    <message>
        <source>Unsolved word</source>
        <translation>Ungelöstes Wort </translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation>Definition aus Wktionary, dem freien Wörterbuch </translation>
    </message>
    <message>
        <source>No definition found</source>
        <translation>Keine Definition gefunden</translation>
    </message>
    <message>
        <source>Unable to connect to Wiktionary</source>
        <translation> Verbindung zum Wiktionary kann nicht hergestellt werden </translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Hindernis </translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Programmsprache auswählen:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Sprache&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notiz</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Starten Sie das Programm neu damit die Sprachänderungen übernommen werden können.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Neues Spiel</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Niedrig </translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Sehr hoch</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Sprache:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Wortlänge:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Anzahl der Wörter:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n buchstaben</numerusform>
            <numerusform>%n buchstaben</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Ringe</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Scores</source>
        <translation>Spielergebnisse </translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Spielergebniss</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Wörter</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Sterne</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Kurvenreich </translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Welle </translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Erfolg </translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Wird geladen</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definitionen</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Hinweis </translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>Spiel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>Auswählen...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>Hinweis </translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>Definitionen</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>Spielergebnisse</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Schliessen</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programm &amp; Sprache...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Spiel auswählen</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Spielnummer:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Entschuldigung</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Das angeforderte Spiel kann nicht gestartet werden. </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Ein Wort unscrambling Spiel </translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 bei Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Definitionen sind von &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Muster: </translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>Fortsetzen </translation>
    </message>
</context>
</TS>

==> connectagram_1.3.3.orig.tar.gz: connectagram-1.3.3/translations/connectagram_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Kette </translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Wird geladen</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Hindernis </translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Programmsprache auswählen:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Sprache&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notiz</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Starten Sie das Programm neu damit die Sprachänderungen übernommen werden können.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Neues Spiel</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Niedrig </translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Sehr hoch</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Sprache:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Wortlänge:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Anzahl der Wörter:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n buchstaben</numerusform>
            <numerusform>%n buchstaben</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Ringe</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Highscores</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Rang</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Ergebnis</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Wörter</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Glückwunsch!</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>Sie haben Ihr bestes Ergebnis geschlagen!</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Gut gemacht!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>Sie haben einen neuen Highscore!</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Sterne</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Kurvenreich </translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Welle </translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Erfolg </translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Wird geladen</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definitionen</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Hinweis </translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>Spiel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>Auswählen...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>Hinweis </translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>Definitionen</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>High&amp;scores</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Strg+H</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Schliessen</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation>&amp;Dunkler Modus</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programm &amp; Sprache...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Spiel auswählen</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Spielnummer:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Entschuldigung</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Das angeforderte Spiel kann nicht gestartet werden. </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Ein Wort unscrambling Spiel </translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 bei Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Definitionen sind von &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Muster: </translation>
    </message>
</context>
</TS>
